#line 2 "cue_scanner.c"

#line 4 "cue_scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer cueparser_create_buffer
#define yy_delete_buffer cueparser_delete_buffer
#define yy_scan_buffer cueparser_scan_buffer
#define yy_scan_string cueparser_scan_string
#define yy_scan_bytes cueparser_scan_bytes
#define yy_init_buffer cueparser_init_buffer
#define yy_flush_buffer cueparser_flush_buffer
#define yy_load_buffer_state cueparser_load_buffer_state
#define yy_switch_to_buffer cueparser_switch_to_buffer
#define yypush_buffer_state cueparserpush_buffer_state
#define yypop_buffer_state cueparserpop_buffer_state
#define yyensure_buffer_stack cueparserensure_buffer_stack
#define yy_flex_debug cueparser_flex_debug
#define yyin cueparserin
#define yyleng cueparserleng
#define yylex cueparserlex
#define yylineno cueparserlineno
#define yyout cueparserout
#define yyrestart cueparserrestart
#define yytext cueparsertext
#define yywrap cueparserwrap
#define yyalloc cueparseralloc
#define yyrealloc cueparserrealloc
#define yyfree cueparserfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define cueparser_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer cueparser_create_buffer
#endif

#ifdef yy_delete_buffer
#define cueparser_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer cueparser_delete_buffer
#endif

#ifdef yy_scan_buffer
#define cueparser_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer cueparser_scan_buffer
#endif

#ifdef yy_scan_string
#define cueparser_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string cueparser_scan_string
#endif

#ifdef yy_scan_bytes
#define cueparser_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes cueparser_scan_bytes
#endif

#ifdef yy_init_buffer
#define cueparser_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer cueparser_init_buffer
#endif

#ifdef yy_flush_buffer
#define cueparser_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer cueparser_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define cueparser_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state cueparser_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define cueparser_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer cueparser_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define cueparserpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state cueparserpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define cueparserpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state cueparserpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define cueparserensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack cueparserensure_buffer_stack
#endif

#ifdef yylex
#define cueparserlex_ALREADY_DEFINED
#else
#define yylex cueparserlex
#endif

#ifdef yyrestart
#define cueparserrestart_ALREADY_DEFINED
#else
#define yyrestart cueparserrestart
#endif

#ifdef yylex_init
#define cueparserlex_init_ALREADY_DEFINED
#else
#define yylex_init cueparserlex_init
#endif

#ifdef yylex_init_extra
#define cueparserlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra cueparserlex_init_extra
#endif

#ifdef yylex_destroy
#define cueparserlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy cueparserlex_destroy
#endif

#ifdef yyget_debug
#define cueparserget_debug_ALREADY_DEFINED
#else
#define yyget_debug cueparserget_debug
#endif

#ifdef yyset_debug
#define cueparserset_debug_ALREADY_DEFINED
#else
#define yyset_debug cueparserset_debug
#endif

#ifdef yyget_extra
#define cueparserget_extra_ALREADY_DEFINED
#else
#define yyget_extra cueparserget_extra
#endif

#ifdef yyset_extra
#define cueparserset_extra_ALREADY_DEFINED
#else
#define yyset_extra cueparserset_extra
#endif

#ifdef yyget_in
#define cueparserget_in_ALREADY_DEFINED
#else
#define yyget_in cueparserget_in
#endif

#ifdef yyset_in
#define cueparserset_in_ALREADY_DEFINED
#else
#define yyset_in cueparserset_in
#endif

#ifdef yyget_out
#define cueparserget_out_ALREADY_DEFINED
#else
#define yyget_out cueparserget_out
#endif

#ifdef yyset_out
#define cueparserset_out_ALREADY_DEFINED
#else
#define yyset_out cueparserset_out
#endif

#ifdef yyget_leng
#define cueparserget_leng_ALREADY_DEFINED
#else
#define yyget_leng cueparserget_leng
#endif

#ifdef yyget_text
#define cueparserget_text_ALREADY_DEFINED
#else
#define yyget_text cueparserget_text
#endif

#ifdef yyget_lineno
#define cueparserget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno cueparserget_lineno
#endif

#ifdef yyset_lineno
#define cueparserset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno cueparserset_lineno
#endif

#ifdef yywrap
#define cueparserwrap_ALREADY_DEFINED
#else
#define yywrap cueparserwrap
#endif

#ifdef yyalloc
#define cueparseralloc_ALREADY_DEFINED
#else
#define yyalloc cueparseralloc
#endif

#ifdef yyrealloc
#define cueparserrealloc_ALREADY_DEFINED
#else
#define yyrealloc cueparserrealloc
#endif

#ifdef yyfree
#define cueparserfree_ALREADY_DEFINED
#else
#define yyfree cueparserfree
#endif

#ifdef yytext
#define cueparsertext_ALREADY_DEFINED
#else
#define yytext cueparsertext
#endif

#ifdef yyleng
#define cueparserleng_ALREADY_DEFINED
#else
#define yyleng cueparserleng
#endif

#ifdef yyin
#define cueparserin_ALREADY_DEFINED
#else
#define yyin cueparserin
#endif

#ifdef yyout
#define cueparserout_ALREADY_DEFINED
#else
#define yyout cueparserout
#endif

#ifdef yy_flex_debug
#define cueparser_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug cueparser_flex_debug
#endif

#ifdef yylineno
#define cueparserlineno_ALREADY_DEFINED
#else
#define yylineno cueparserlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define cueparserwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 63
#define YY_END_OF_BUFFER 64
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[496] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       64,   62,   57,   61,   62,   62,   58,   58,   59,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   57,   60,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,   52,   51,   53,   52,   52,
       52,   54,   55,   63,   63,   56,   57,    0,    2,    0,
        0,    1,    0,   58,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,   57,   60,    3,    3,    2,    3,
        3,    1,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,   51,    0,    0,    0,   54,   55,
        0,   56,    2,    1,   25,    0,    0,    0,    0,    0,
        0,    0,   24,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   11,    0,    0,   23,   44,    0,    0,    0,
        0,    0,    0,    0,    0,    2,    1,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    0,    0,
        0,    9,    0,    0,    0,    0,    0,    0,    0,    6,
       12,    0,    0,    0,   43,    0,    0,    0,    0,    0,
        0,   26,    0,    0,    0,    0,    0,    0,   10,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,   45,    0,    0,
        0,   14,    0,    0,    0,    0,    0,   22,   37,   28,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

       30,    0,   13,    0,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,   46,    0,    0,
        7,    0,    0,    0,    0,   41,    0,    0,    0,    0,
        0,    0,   27,    0,    0,    0,    0,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    0,    0,    4,    0,    0,   36,
       35,    0,    0,    0,    0,   29,    0,    0,    0,   40,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    0,   34,    0,   33,    0,

        0,    0,    0,    8,    0,    0,    0,    0,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        0,    0,    0,    0,    0,    0,    0,    0,   31,   42,
        0,   38,   39,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    0,    5,   15,   16,   18,
       20,   17,   19,   21,   32,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       47,   48,   49,   50,    0

    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    5,    1,
        1,    1,    1,    1,    1,    1,    6,    7,    8,    9,
       10,   11,   12,   13,   14,   15,   14,   16,    1,    1,
        1,    1,    1,    1,   17,   18,   19,   20,   21,   22,
       23,   24,   25,    1,   26,   27,   28,   29,   30,   31,
        1,   32,   33,   34,   35,   36,   37,   38,   39,   40,
        1,   41,    1,    1,   42,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[43] =
    {   0,
        1,    2,    2,    1,    1,    1,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1
    } ;

static const flex_int16_t yy_base[507] =
    {   0,
        0,   41,   44,   85,   87,   89,   91,   93,  603,  602,
      604,  607,  601,  607,   93,   94,    0,  583,  607,   73,
      576,   83,   92,   77,  579,   85,   85,   99,  578,  103,
      100,  567,  580,  121,  607,    0,  134,  137,  172,  577,
        0,  116,  570,  126,  125,  120,  573,  120,  131,  133,
      572,  139,  141,  561,  574,  607,  588,  607,  572,  567,
      566,    0,  584,  607,  582,  607,  582,  151,  607,  153,
      154,  607,  155,    0,  559,  560,  549,  560,  550,  544,
      543,  548,  544,  541,  546,  555,  542,  550,  537,  535,
      154,  557,  534,  532,  543,  535,  534,  521,  531,  525,

      539,  540,  537,  519,  124,  607,    0,  187,    0,  195,
      165,    0,  198,    0,  530,  531,  520,  531,  521,  515,
      514,  519,  515,  512,  517,  526,  513,  521,  508,  506,
      173,  528,  505,  503,  514,  506,  505,  492,  502,  496,
      510,  511,  508,  490,  523,  490,  494,  491,    0,  519,
      517,  607,  168,  171,  607,  497,  501,  492,  499,  498,
      493,  482,  607,  493,  490,  185,  478,  488,  489,  474,
      485,  475,  607,  482,  469,  479,  607,  468,  479,  476,
      471,  455,  477,  453,  473,  211,  214,    0,  471,  475,
      466,  473,  472,  467,  456,    0,  467,  464,  199,  452,

      462,  463,  448,  459,  449,    0,  456,  443,  453,    0,
      442,  453,  450,  445,  429,  451,  427,  447,  446,  434,
      438,  607,  435,  433,  430,  434,  422,  429,  416,  607,
      607,  424,  435,  417,  452,  436,  202,  420,  421,  427,
      432,  607,  406,  410,  425,  420,  418,  422,  607,    0,
      413,  411,  408,  412,  400,  407,  394,    0,    0,  402,
      413,  395,  430,  414,  212,  398,  399,  405,  410,    0,
      384,  388,  403,  398,  396,  400,    0,  607,  399,  402,
      395,  607,  378,  386,  381,  381,  388,  607,  607,  607,
      221,  389,  405,  404,  379,  376,  390,  375,  380,  372,

      607,  374,  607,  385,  378,    0,  361,  369,  364,  364,
      371,    0,    0,    0,  372,  388,  387,  362,  359,  373,
      358,  363,  355,    0,  357,    0,  368,  607,  345,  362,
      607,  359,  359,  359,  359,  607,  357,  368,  367,  348,
      346,  342,  607,  343,  346,  348,  340,  347,    0,  344,
      344,  344,  344,  342,  353,  352,  333,  331,  327,    0,
      328,  331,  333,  325,  330,  320,  607,  326,  318,  607,
      607,  195,  217,  332,  327,  607,  325,  312,  315,  607,
      312,    0,  318,  310,    0,    0,  219,  223,  324,  319,
        0,  317,  304,  307,    0,  319,  607,  308,  607,  323,

      321,  321,  230,  607,  299,  300,  308,  223,    0,  301,
        0,  316,  314,  314,  233,    0,  292,  293,  301,  226,
      296,  299,  304,  309,  302,  237,  307,  306,  607,  607,
      282,  607,  607,  292,  297,  302,  295,  238,  300,  299,
        0,    0,  275,    0,    0,  277,  607,  607,  607,  607,
      607,  607,  607,  607,  607,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  263,  220,  277,  271,  284,  284,
      265,  280,  270,  271,  254,  253,  225,  226,  277,  272,
      275,  270,  265,  272,  263,  266,  245,  227,  209,  151,
      607,  607,  607,  607,  607,  257,  260,  263,  266,  269,

       98,  272,  275,  278,  281,  284
    } ;

static const flex_int16_t yy_def[507] =
    {   0,
      495,    1,  495,    3,  496,  496,  497,  497,  498,  498,
      495,  495,  495,  495,  499,  500,  501,  501,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  502,  503,  504,  502,   39,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  495,  495,  495,  495,  495,
      495,  505,  495,  495,  506,  495,  495,  499,  495,  499,
      500,  495,  500,  501,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  502,  503,  502,  503,
      504,  502,  504,   39,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  495,  495,  495,  495,  505,  495,
      506,  495,  499,  500,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  503,  504,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,

      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  502,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495,  495,  495,  502,  502,
      502,  502,  502,  502,  502,  502,  502,  502,  502,  502,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  502,  502,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  502,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  502,  502,  502,  502,  502,
      502,  502,  502,  502,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,    0,  495,  495,  495,  495,  495,

      495,  495,  495,  495,  495,  495
    } ;

static const flex_int16_t yy_nxt[650] =
    {   0,
       12,   13,   14,   15,   16,   12,   17,   17,   17,   17,
       18,   17,   17,   17,   17,   19,   20,   21,   22,   23,
       12,   24,   25,   12,   26,   12,   12,   27,   12,   12,
       28,   29,   30,   31,   32,   12,   33,   12,   12,   12,
       12,   12,   34,   35,   36,   13,   14,   37,   38,   36,
       39,   39,   39,   39,   40,   39,   39,   39,   39,   41,
       42,   43,   44,   45,   36,   46,   47,   36,   48,   36,
       36,   49,   36,   36,   50,   51,   52,   53,   54,   36,
       55,   36,   36,   36,   36,   36,   34,   35,   57,   58,
       57,   58,   63,   64,   63,   64,   69,   76,   72,   80,

       74,   85,   81,   86,   77,   90,   59,   78,   59,   60,
       83,   60,   82,   88,   91,   92,   84,   89,   61,   93,
       61,   97,  105,  106,  100,  105,  106,   98,   94,  101,
       95,  102,   99,   70,   73,   68,   68,  109,   71,   71,
      116,  112,  120,  123,  125,  121,  126,  117,  128,  124,
      118,  130,  129,  133,   69,  122,  153,  137,   72,  154,
      131,  132,  134,  138,  135,  140,   71,   71,  139,  112,
      141,   69,  142,  171,  110,   72,  494,  113,  114,  114,
      114,  114,  114,  114,  114,  114,  114,  172,   68,   68,
      109,   70,  204,   70,   73,   73,   68,   68,  186,   71,

       71,  400,  187,  231,  401,  113,  205,  232,   70,  293,
      294,   73,   68,   68,  109,   71,   71,  259,  112,  316,
      317,  260,  291,  402,  336,  412,  403,  110,  413,  414,
      432,  433,  415,  444,  445,  110,  467,  493,  113,  426,
      427,  428,  438,  439,  440,  451,  460,  479,  481,  452,
      461,  110,  492,  468,  113,  480,  482,   56,   56,   56,
       62,   62,   62,   65,   65,   65,   68,   68,   68,   71,
       71,   71,  107,  491,  107,  108,  108,  108,  111,  111,
      111,  149,  490,  149,  151,  151,  151,  489,  488,  487,
      486,  485,  484,  483,  478,  477,  476,  475,  474,  473,

      472,  471,  470,  469,  466,  465,  464,  463,  462,  459,
      458,  457,  456,  455,  454,  453,  450,  449,  448,  447,
      446,  443,  442,  441,  437,  436,  435,  434,  431,  430,
      429,  425,  424,  423,  422,  421,  420,  419,  418,  417,
      416,  411,  410,  409,  408,  407,  406,  405,  404,  399,
      398,  397,  396,  395,  394,  393,  392,  391,  390,  389,
      388,  387,  386,  385,  384,  383,  382,  381,  380,  379,
      378,  377,  376,  375,  374,  373,  372,  371,  370,  369,
      368,  367,  366,  365,  364,  363,  362,  361,  360,  359,
      358,  357,  356,  355,  354,  353,  352,  351,  350,  349,

      348,  347,  346,  345,  344,  343,  342,  341,  340,  339,
      338,  337,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,
      315,  291,  314,  313,  312,  311,  310,  309,  308,  307,
      306,  305,  304,  303,  302,  301,  300,  299,  298,  297,
      296,  295,  292,  291,  290,  289,  288,  287,  286,  285,
      284,  283,  282,  281,  280,  279,  278,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  268,  267,  266,  265,
      264,  263,  262,  261,  258,  257,  256,  255,  254,  253,
      252,  251,  250,  249,  248,  247,  246,  245,  244,  243,

      242,  241,  240,  239,  238,  237,  236,  235,  234,  233,
      230,  229,  228,  227,  226,  225,  224,  223,  222,  152,
      150,  221,  220,  219,  145,  218,  217,  216,  215,  214,
      213,  212,  211,  210,  209,  208,  207,  206,  203,  202,
      201,  200,  199,  198,  197,  196,  195,  194,  193,  192,
      191,  190,  189,  188,  185,  184,  183,  182,  181,  180,
      179,  178,  177,  176,  175,  174,  173,  170,  169,  168,
      167,  166,  165,  164,  163,  162,  161,  160,  159,  158,
      157,  156,  155,   67,  152,  150,  148,  147,  146,  145,
      144,  143,  136,  127,  119,  115,  104,  103,   96,   87,

       79,   75,   67,  495,   66,   66,   11,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495
    } ;

static const flex_int16_t yy_chk[650] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    2,    2,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    4,    4,    5,    5,
        6,    6,    7,    7,    8,    8,   15,   20,   16,   22,

      501,   24,   22,   24,   20,   27,    5,   20,    6,    5,
       23,    6,   22,   26,   27,   27,   23,   26,    5,   28,
        6,   30,   34,   34,   31,  105,  105,   30,   28,   31,
       28,   31,   30,   15,   16,   37,   37,   37,   38,   38,
       42,   38,   44,   45,   46,   44,   46,   42,   48,   45,
       42,   49,   48,   50,   68,   44,   70,   52,   71,   73,
       49,   49,   50,   52,   50,   53,  111,  111,   52,  111,
       53,  153,   53,   91,   37,  154,  490,   38,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   91,  108,  108,
      108,   68,  131,   70,   71,   73,  110,  110,  110,  113,

      113,  372,  113,  166,  372,  111,  131,  166,  153,  237,
      237,  154,  186,  186,  186,  187,  187,  199,  187,  265,
      265,  199,  291,  373,  291,  387,  373,  108,  387,  388,
      408,  408,  388,  420,  420,  110,  466,  489,  113,  403,
      403,  403,  415,  415,  415,  426,  438,  477,  478,  426,
      438,  186,  488,  466,  187,  477,  478,  496,  496,  496,
      497,  497,  497,  498,  498,  498,  499,  499,  499,  500,
      500,  500,  502,  487,  502,  503,  503,  503,  504,  504,
      504,  505,  486,  505,  506,  506,  506,  485,  484,  483,
      482,  481,  480,  479,  476,  475,  474,  473,  472,  471,

      470,  469,  468,  467,  465,  446,  443,  440,  439,  437,
      436,  435,  434,  431,  428,  427,  425,  424,  423,  422,
      421,  419,  418,  417,  414,  413,  412,  410,  407,  406,
      405,  402,  401,  400,  398,  396,  394,  393,  392,  390,
      389,  384,  383,  381,  379,  378,  377,  375,  374,  369,
      368,  366,  365,  364,  363,  362,  361,  359,  358,  357,
      356,  355,  354,  353,  352,  351,  350,  348,  347,  346,
      345,  344,  342,  341,  340,  339,  338,  337,  335,  334,
      333,  332,  330,  329,  327,  325,  323,  322,  321,  320,
      319,  318,  317,  316,  315,  311,  310,  309,  308,  307,

      305,  304,  302,  300,  299,  298,  297,  296,  295,  294,
      293,  292,  287,  286,  285,  284,  283,  281,  280,  279,
      276,  275,  274,  273,  272,  271,  269,  268,  267,  266,
      264,  263,  262,  261,  260,  257,  256,  255,  254,  253,
      252,  251,  248,  247,  246,  245,  244,  243,  241,  240,
      239,  238,  236,  235,  234,  233,  232,  229,  228,  227,
      226,  225,  224,  223,  221,  220,  219,  218,  217,  216,
      215,  214,  213,  212,  211,  209,  208,  207,  205,  204,
      203,  202,  201,  200,  198,  197,  195,  194,  193,  192,
      191,  190,  189,  185,  184,  183,  182,  181,  180,  179,

      178,  176,  175,  174,  172,  171,  170,  169,  168,  167,
      165,  164,  162,  161,  160,  159,  158,  157,  156,  151,
      150,  148,  147,  146,  145,  144,  143,  142,  141,  140,
      139,  138,  137,  136,  135,  134,  133,  132,  130,  129,
      128,  127,  126,  125,  124,  123,  122,  121,  120,  119,
      118,  117,  116,  115,  104,  103,  102,  101,  100,   99,
       98,   97,   96,   95,   94,   93,   92,   90,   89,   88,
       87,   86,   85,   84,   83,   82,   81,   80,   79,   78,
       77,   76,   75,   67,   65,   63,   61,   60,   59,   57,
       55,   54,   51,   47,   43,   40,   33,   32,   29,   25,

       21,   18,   13,   11,   10,    9,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  495,  495,  495,  495
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[64] =
    {   0,
1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 
    1, 1, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "cue_scanner.l"
#line 2 "cue_scanner.l"
/*
 * Copyright (c) 2004, 2005, 2006, 2007, Svend Sorensen
 * Copyright (c) 2009, 2010 Jochen Keil
 * For license terms, see the file COPYING in this distribution.
 */

#include <stdlib.h>
#include <string.h>

#include "cd.h"
#include "cue_parser.h"

char cueparser_buffer[PARSER_BUFFER];

int cueparserlex(void);
#line 1055 "cue_scanner.c"
#define YY_NO_INPUT 1

#line 1058 "cue_scanner.c"

#define INITIAL 0
#define NAME 1
#define REM 2
#define RPG 3
#define SKIP 4

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 33 "cue_scanner.l"


#line 1275 "cue_scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 496 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 607 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
#line 36 "cue_scanner.l"
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 36 "cue_scanner.l"
{
		cueparserlval.sval = strncpy(	cueparser_buffer,
					++yytext,
					(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng));
		cueparserlval.sval[(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng) - 2] = '\0';
		BEGIN(INITIAL);
		return STRING;
		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 45 "cue_scanner.l"
{
		cueparserlval.sval = strncpy(	cueparser_buffer,
					yytext,
					(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng));
		cueparserlval.sval[(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng)] = '\0';
		BEGIN(INITIAL);
		return STRING;
		}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 54 "cue_scanner.l"
{ BEGIN(NAME); return CATALOG; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 55 "cue_scanner.l"
{ BEGIN(NAME); return CDTEXTFILE; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 57 "cue_scanner.l"
{ BEGIN(NAME); return FFILE; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 58 "cue_scanner.l"
{ return BINARY; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 59 "cue_scanner.l"
{ return MOTOROLA; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 60 "cue_scanner.l"
{ return AIFF; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 61 "cue_scanner.l"
{ return WAVE; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 62 "cue_scanner.l"
{ return MP3; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 63 "cue_scanner.l"
{ return FLAC; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 65 "cue_scanner.l"
{ return TRACK; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 66 "cue_scanner.l"
{ cueparserlval.ival = MODE_AUDIO; return AUDIO; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 67 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE1; return MODE1_2048; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 68 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE1_RAW; return MODE1_2352; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 69 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE2; return MODE2_2336; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 70 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE2_FORM1; return MODE2_2048; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 71 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE2_FORM2; return MODE2_2342; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 72 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE2_FORM_MIX; return MODE2_2332; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 73 "cue_scanner.l"
{ cueparserlval.ival = MODE_MODE2_RAW; return MODE2_2352; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 75 "cue_scanner.l"
{ return FLAGS; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 76 "cue_scanner.l"
{ cueparserlval.ival = FLAG_PRE_EMPHASIS; return PRE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 77 "cue_scanner.l"
{ cueparserlval.ival = FLAG_COPY_PERMITTED; return DCP; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 78 "cue_scanner.l"
{ cueparserlval.ival = FLAG_FOUR_CHANNEL; return FOUR_CH; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 79 "cue_scanner.l"
{ cueparserlval.ival = FLAG_SCMS; return SCMS; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 81 "cue_scanner.l"
{ return PREGAP; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 82 "cue_scanner.l"
{ return INDEX; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 83 "cue_scanner.l"
{ return POSTGAP; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 85 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_TITLE;  return TITLE; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 86 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_PERFORMER;  return PERFORMER; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 87 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_SONGWRITER;  return SONGWRITER; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 88 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_COMPOSER;  return COMPOSER; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 89 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_ARRANGER;  return ARRANGER; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 90 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_MESSAGE;  return MESSAGE; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 91 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_DISC_ID;  return DISC_ID; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 92 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_GENRE;  return GENRE; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 93 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_TOC_INFO1;  return TOC_INFO1; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 94 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_TOC_INFO2;  return TOC_INFO2; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 95 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_UPC_ISRC;  return UPC_EAN; }
	YY_BREAK
case 41:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 96 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_UPC_ISRC;  return ISRC; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 97 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_SIZE_INFO;  return SIZE_INFO; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 99 "cue_scanner.l"
{ BEGIN(NAME); return TRACK_ISRC; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 101 "cue_scanner.l"
{ BEGIN(REM); /* exclusive rules for special exceptions */ }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 103 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = REM_DATE; return DATE; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 104 "cue_scanner.l"
{ BEGIN(NAME); cueparserlval.ival = PTI_GENRE; return XXX_GENRE; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 105 "cue_scanner.l"
{ BEGIN(RPG); cueparserlval.ival = REM_REPLAYGAIN_ALBUM_GAIN;
							return REPLAYGAIN_ALBUM_GAIN; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 107 "cue_scanner.l"
{ BEGIN(RPG); cueparserlval.ival = REM_REPLAYGAIN_ALBUM_PEAK;
							return REPLAYGAIN_ALBUM_PEAK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 109 "cue_scanner.l"
{ BEGIN(RPG); cueparserlval.ival = REM_REPLAYGAIN_TRACK_GAIN;
							return REPLAYGAIN_TRACK_GAIN; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 111 "cue_scanner.l"
{ BEGIN(RPG); cueparserlval.ival = REM_REPLAYGAIN_TRACK_PEAK;
							return REPLAYGAIN_TRACK_PEAK; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 114 "cue_scanner.l"
{ BEGIN(REM); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 115 "cue_scanner.l"
{ BEGIN(REM); }
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 116 "cue_scanner.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 118 "cue_scanner.l"
{
		cueparserlval.sval = strncpy(	cueparser_buffer,
					yytext,
					(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng));
		cueparserlval.sval[(yyleng > sizeof(cueparser_buffer) ? sizeof(cueparser_buffer) : yyleng)] = '\0';
		BEGIN(SKIP);
		return STRING;
		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 127 "cue_scanner.l"
{ BEGIN(RPG); }
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 129 "cue_scanner.l"
{ BEGIN(INITIAL); yylineno++; return '\n'; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 131 "cue_scanner.l"
{ /* ignore whitespace */ }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "cue_scanner.l"
{ cueparserlval.ival = atoi(yytext); return NUMBER; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "cue_scanner.l"
{ return yytext[0]; }
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 136 "cue_scanner.l"
{ yylineno++; /* blank line */ }
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
#line 137 "cue_scanner.l"
{ yylineno++; return '\n'; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 138 "cue_scanner.l"
{ fprintf(stderr, "bad character '%c'\n", yytext[0]); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 140 "cue_scanner.l"
ECHO;
	YY_BREAK
#line 1689 "cue_scanner.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(NAME):
case YY_STATE_EOF(REM):
case YY_STATE_EOF(RPG):
case YY_STATE_EOF(SKIP):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 496 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 496 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 495);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
	if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 140 "cue_scanner.l"


